@@ -110,7 +110,10 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
             if (cookieStore.getCookies().size() == 0) {
                 throw ApiFacadeException.internalServerError("No cookies received.");
             }
-            return new SessionData(responseBody.getSession(), cookieStore.getCookies());
+            SessionData sessionData = new SessionData(responseBody.getSession(), cookieStore.getCookies());
+            sessionData.setProperty(SessionData.PROPERTY_CONTEXT_ID, Long.toString(responseBody.getContextId()));
+            sessionData.setProperty(SessionData.PROPERTY_USER_ID, Long.toString(responseBody.getUserId()));
+            return sessionData;
         } catch (Exception e) {
             if (e instanceof ConnectTimeoutException) {
                 throw ApiFacadeException.gatewayTimeoutError(e);
@@ -127,7 +130,7 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
         RequestBuilder builder = RequestBuilder.post(createUrl());
         builder.setCharset(Charset.forName("UTF-8"));
         String hostname = credentials.getHost();
-        if (!Strings.isEmpty(hostname)) {
+        if (credentials.getHostConfiguration().isForwardHostHeader() && !Strings.isEmpty(hostname)) {
             builder.addHeader(RequestUtil.HEADER_HOST, hostname);
         }
         String forwardedFor = credentials.getForwardedFor();
@@ -138,6 +141,10 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
         if (userAgent != null) {
             builder.addHeader(RequestUtil.HEADER_USER_AGENT, userAgent);
         }
+        String trackingId = credentials.getTrackingId();
+        if (trackingId != null) {
+            builder.addParameter("trackingId", trackingId);
+        }
         return builder
                 .addParameter("action", "login")
                 .addParameter("name", credentials.getUsername())
@@ -151,14 +158,14 @@ public class LoginConnector implements Connector<SessionData, LoginResponseMto>
         try {
             StatusLine statusLine = response.getStatusLine();
             int statusCode = statusLine.getStatusCode();
+            HttpEntity entity = response.getEntity();
+            if (log.isDebugEnabled()) {
+                entity = new BufferedHttpEntity(response.getEntity());
+                ByteArrayOutputStream baos = new ByteArrayOutputStream();
+                entity.writeTo(baos);
+                log.debug(new String(baos.toByteArray(), "UTF-8"));
+            }
             if (statusCode == 200) {
-                HttpEntity entity = response.getEntity();
-                if (log.isDebugEnabled()) {
-                    entity = new BufferedHttpEntity(response.getEntity());
-                    ByteArrayOutputStream baos = new ByteArrayOutputStream();
-                    entity.writeTo(baos);
-                    log.debug(new String(baos.toByteArray(), "UTF-8"));
-                }
                 ObjectMapper mapper = JacksonUtil.getMapper();
                 LoginResponseMto responseBody = mapper.readValue(entity.getContent(), LoginResponseMto.class);
                 EntityUtils.consume(entity);
