@@ -85,6 +85,10 @@ public class ApiFacadeException extends WebApplicationException {
 
         int REDIRECT = 10;
 
+        int SERVICE_UNAVAILABLE = 11;
+
+        int PASSWORD_OF_SECONDARY_MAIL_ACCOUNT_CHANGED = 12;
+
         String INVALID_SESSION = "SES-206";
 
         int CLIENT_UPDATE_MANDATORY = 900;
@@ -110,6 +114,10 @@ public class ApiFacadeException extends WebApplicationException {
             return invalidSession();
         } else if (areCredentialsInvalid(code)) {
             return invalidCredentials();
+        } else if (isDatabaseUpdate(code)) {
+            return serviceUnavailable();
+        } else if (isPasswordOfSecondaryAccountChanged(code)) {
+            return passwordSecondaryAccountChanged();
         } else if (isRedirect(code)) {
             return redirect(error);
         }
@@ -129,6 +137,14 @@ public class ApiFacadeException extends WebApplicationException {
         return "MSG-1000".equals(code) || "LGI-0006".equals(code);
     }
 
+    private static boolean isDatabaseUpdate(String code) {
+        return "CTX-0007".equals(code);
+    }
+
+    private static boolean isPasswordOfSecondaryAccountChanged(String code) {
+        return "MSG-1016".equals(code);
+    }
+
     private static boolean isRedirect(String code) {
         return "LGI-0016".equals(code);
     }
@@ -227,4 +243,12 @@ public class ApiFacadeException extends WebApplicationException {
         return create(Status.BAD_REQUEST, Code.INVALID_ACCOUNT_DATA, "Invalid account data");
     }
 
+    public static ApiFacadeException serviceUnavailable() {
+        return create(Status.SERVICE_UNAVAILABLE, Code.SERVICE_UNAVAILABLE, "Service unavailable");
+    }
+
+    public static ApiFacadeException passwordSecondaryAccountChanged() {
+        return create(Status.SERVICE_UNAVAILABLE, Code.PASSWORD_OF_SECONDARY_MAIL_ACCOUNT_CHANGED, "Password of secondary mail account changed");
+    }
+
 }
