@@ -193,6 +193,10 @@ public class RequestUtil {
         if (userId != null) {
             sessionData.setProperty(SessionData.PROPERTY_USER_ID, userId);
         }
+        Map<String, String> customProperties = configuration.getCustomProperties();
+        if (customProperties.size() > 0) {
+            sessionData.getProperties().putAll(customProperties);
+        }
         return sessionData
                 .withHost(hostname)
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
